; ________________________________________________
; |      Costanti per timer 4 digit 16F628A      |
; |______________________________________________|
; |   Header File                                |
; |______________________________________________|
; |   Tipo      : INC                            |
; |   Versione  : 1                              |
; |   Release   : 0                              |
; |   Autore    : Lain Walter                    |
; |   Data      :  7/08/07                       |
; |______________________________________________|

;_______________________________________________________Costanti
#define c_TRISA_VALUE   0xF0            ;PORTA 7-4 in, PORTA 3-0 OUT
#define c_TRISB_VALUE   0xF3            ;PORTB 7-4,1-0 in, PORTB 3-2 OUT
#define c_TMR_CTRL      0x00            ;Seleziona mod. Timer1 (Fosc/4), sinc. su CK interno
                                        ; e setta prescaler a 1

#define c_REG_CP_TRIS   TRISA           ;pin clock dei registri
#define c_REG_CP_PORT   PORTA
#define c_REG_CP_PIN    0

#define c_REG_STB_TRIS  TRISA           ;pin strobe dei registri
#define c_REG_STB_PORT  PORTA
#define c_REG_STB_PIN   1

#define c_REG_OE_TRIS   TRISA           ;pin output enable dei registri
#define c_REG_OE_PORT   PORTA
#define c_REG_OE_PIN    2

#define c_REG_DATA_TRIS TRISA           ;pin data dei registri
#define c_REG_DATA_PORT PORTA
#define c_REG_DATA_PIN  3

#define c_SW_IN_TRIS    TRISB           ;pin ingresso pulsanti
#define c_SW_IN_PORT    PORTB
#define c_SW_IN_PIN     1

#define c_SW_ST_TRIS    TRISB           ;pin pulsante start/stop
#define c_SW_ST_PORT    PORTB
#define c_SW_ST_PIN     0

#define c_LED_GREEN_TRIS TRISB           ;pin da alzare per led verde
#define c_LED_GREEN_PORT PORTB
#define c_LED_GREEN_PIN 2

#define c_LED_RED_TRIS  TRISB           ;pin da alzare per led rosso
#define c_LED_RED_PORT  PORTB
#define c_LED_RED_PIN   3

;_______________________________________________________Pulsanti
#define c_SW_BIT        4               ;bit da controllare per buffer tasti
                                        ; con il clock a 10ms, occorrono 160ms
                                        ; per un cambio stato del pulsante

;_______________________Timer Principale
;timer principale di sistema (0x61A8 = 5 ms)
;clock=20MHz --> tmr=5MHz / 200ns
; Dato che il timer incrementa fino a FFFF e poi va in IRQ, devo sottrarre
; il valore che mi serve da FFFF e quindi usare il risultato
#define c_TMR_TIME_H    0x9F            ;timer principale
#define c_TMR_TIME_L    0x51            ; (modificato per temp. esatta)
;_______________________Divisori timer principale
#define c_TMR_TIME2     0x64            ;divisore timer 2 (500ms)


;_______________________________________________________Flags
#define f_SW_SEL_STAT   b_SW_CTRL,0     ;flag di stato pulsante selezione
#define f_SW_SEL_CHG    b_SW_CTRL,1     ;flag di cambio stato pulsante selezione
#define f_SW_ADD_STAT   b_SW_CTRL,2     ;flag di stato pulsante add
#define f_SW_ADD_CHG    b_SW_CTRL,3     ;flag di cambio stato pulsante add
#define f_SW_SUB_STAT   b_SW_CTRL,4     ;flag di stato pulsante sub
#define f_SW_SUB_CHG    b_SW_CTRL,5     ;flag di cambio stato pulsante sub
#define f_SW_STST_STAT  b_SW_CTRL,6     ;flag di stato pulsante start/stop
#define f_SW_STST_CHG   b_SW_CTRL,7     ;flag di cambio stato pulsante start/stop 

#define f_FIRST         b_CONTROLLO,0   ;flag per selezione display0 e pulsante SEL
#define f_SECOND        b_CONTROLLO,1   ;flag per selezione display1 e pulsante ADD
#define f_THIRD         b_CONTROLLO,2   ;flag per selezione display2 e pulsante SUB
#define f_FOURTH        b_CONTROLLO,3   ;flag per selezione display3
#define f_REL_CMD       b_CONTROLLO,4   ;flag controllo relè
#define f_TIMER1_ON     b_CONTROLLO,6   ;flag IRQ timer1
#define f_TIMER3        b_CONTROLLO,7   ;flag timer3

#define f_MODE          b_STATO,0       ;flag stato conteggio (1=min, 0=sec)
#define f_DOT_BLINK     b_STATO,1       ;flag per lampeggio punto
#define f_TMR_END       b_STATO,2       ;flag per fine conteggio
#define f_INIT          b_STATO,3       ;flag per stato sistema (1=OK, 0=init)
#define f_DISP_BLINK    b_STATO,5       ;flag per lampeggio display

#define f_DISP0_SEL     b_DISP_SEL,0    ;flag selezione display 0
#define f_DISP1_SEL     b_DISP_SEL,1    ;flag selezione display 1
#define f_DISP2_SEL     b_DISP_SEL,2    ;flag selezione display 2
#define f_DISP3_SEL     b_DISP_SEL,3    ;flag selezione display 3

;_______________________________________________________Caratteri BCD
;       ABCDEFG DP
; A --> 1110111 0
#define CHAR_A          B'11101110'
; B --> 0011111 0
#define CHAR_B          B'00111110'
; C --> 0001101 0
#define CHAR_C          B'00011010'
; D --> 0111101 0
#define CHAR_D          B'01111010'
; E --> 1001111 0
#define CHAR_E          B'10011110'
; F --> 1000111 0
#define CHAR_F          B'10001110'
; G --> 1011110 0
#define CHAR_G          B'10111100'
; H --> 0110111 0
#define CHAR_H          B'01101110'
; I --> 0000110 0
#define CHAR_I          B'00001100'
; J --> 0111000 0
#define CHAR_J          B'01110000'
; K --> 0100111 0
#define CHAR_K          B'01001110'
; L --> 0001110 0
#define CHAR_L          B'00011100'
; M --> 1110110 0
#define CHAR_M          B'11101100'
; N --> 0010101 0
#define CHAR_N          B'00101010'
; O --> 0011101 0
#define CHAR_O          B'00111010'
; P --> 1100111 0
#define CHAR_P          B'11001110'
; Q --> 1110011 0
#define CHAR_Q          B'11100110'
; R --> 0000101 0
#define CHAR_R          B'00001010'
; S --> 1011011 0
#define CHAR_S          B'10110110'
; T --> 1110000 0
#define CHAR_T          B'11100000'
; U --> 0011100 0
#define CHAR_U          B'00111000'
; V --> 0111100 0
#define CHAR_V          B'00111100'
; W --> 0111111 0
#define CHAR_W          B'01111110'
; X --> 0110001 0
#define CHAR_X          B'01100010'
; Y --> 0111011 0
#define CHAR_Y          B'01110110'
; Z --> 1101101 0
#define CHAR_Z          B'11011010'
; 0 --> 1111110 0
#define CHAR_0          B'11111100'
#define CHAR_0DP        B'11111101'
; 1 --> 0110000 0
#define CHAR_1          B'01100000'
#define CHAR_1DP        B'01100001'
; 2 --> 1101101 0
#define CHAR_2          B'11011010'
#define CHAR_2DP        B'11011011'
; 3 --> 1111001 0
#define CHAR_3          B'11110010'
#define CHAR_3DP        B'11110011'
; 4 --> 0111011 0
#define CHAR_4          B'01100110'
#define CHAR_4DP        B'01100111'
; 5 --> 1011011 0
#define CHAR_5          B'10110110'
#define CHAR_5DP        B'10110111'
; 6 --> 1011111 0
#define CHAR_6          B'10111110'
#define CHAR_6DP        B'10111111'
; 7 --> 1110000 0
#define CHAR_7          B'11100000'
#define CHAR_7DP        B'11100001'
; 8 --> 1111111 0
#define CHAR_8          B'11111110'
#define CHAR_8DP        B'11111111'
; 9 --> 1111011 0
#define CHAR_9          B'11110110'
#define CHAR_9DP        B'11110111'
; - --> 0000001 0
#define CHAR_LINE       B'00000010'
;   --> 0000000 0
#define CHAR_VOID       B'00000000'

