; ________________________________________________
; |       Programma timer 4 digit 16F628A        |
; |______________________________________________|
; |   Src File                                   |
; |______________________________________________|
; |   Tipo      : ASM                            |
; |   Versione  : 1                              |
; |   Release   : 0                              |
; |   Autore    : Lain Walter                    |
; |   Data      :  7/08/07                       |
; |______________________________________________|

        LIST

    __CONFIG 0x2162
; Program code protection: OFF
; Data code protection: OFF
; LVP: OFF
; BODEN: ON
; MCLRE: external
; FOSC2,1,0: hi-speed xtal
; PWRT: ON
; WDT: OFF
 

#include "P16F628A.inc"
#include "costanti.inc"
#include "variabili.inc"
#include "macro.inc"


;***************************************************************************
;                                   RESET
;***************************************************************************

 ORG RESET_VECTOR
        GOTO SYS_STARTUP


;***************************************************************************
;                                INTERRUPTS
;***************************************************************************

 ORG INTERRUPT_VECTOR

        PUSH                            ;
        BANKSET 0                       ;Bank0
        BTFSS PIR1,TMR1IF               ;Controlla flag IRQ Timer1
        GOTO INT_END                    ; non attivo, prosegue
        MOVLW c_TMR_TIME_H              ;ricarica timer1 aggiungendo
        ADDWF TMR1H,F                   ; il valore in modo da non perdere
        MOVLW c_TMR_TIME_L              ; i cicli del vettore IRQ
        ADDWF TMR1L,F
        CLRF PIR1                       ;
        BANKSET 1                       ;Bank1
        BSF PIE1,TMR1IE                 ;Abilita IRQ Timer1
        BANKSET 0                       ;Bank0
        BSF f_TIMER1_ON                 ;attiva flag timer1
INT_END POP                             ;
        RETFIE


;***************************************************************************
;                             START-UP SISTEMA
;***************************************************************************
SYS_STARTUP:

        CLI                             ;Disabilita master IRQ
        CALL Sys_Init                   ;Inizializza il sistema
        CALL Timer_Init                 ;Inizializza i timer
        BSF f_FIRST                     ;seleziona primo display
        BSF f_DISP0_SEL
        BSF INTCON,PEIE                 ;Abilita IRQ periferiche
        SEI                             ;Abilita master IRQ

        CALL Display_Init
        BSF f_INIT                      ;modalità init
        BCF f_MODE                      ;modo 0 (conteggio secondi)
        BCF f_REL_CMD                   ;disattiva relè
        BSF c_LED_GREEN_PORT,c_LED_GREEN_PIN ;attiva led verde
        BCF c_LED_RED_PORT,c_LED_RED_PIN


;***************************************************************************
;                           PROGRAMMA PRINCIPALE
;***************************************************************************
PROGRAM:
        BTFSS f_INIT                    ;verifica se sistema in init
        GOTO P_INIT                     ; non è in init, salta sequenza

        CALL Led_Change                 ;se in init, led e' arancio
        BTFSS f_SW_STST_STAT            ;verifica se premuto "start"
        GOTO P_INIT                     ;no, prosegue
        BTFSS f_SW_STST_CHG             ;si, verifica se cambio stato
        GOTO P_INIT                     ;no, prosegue
        BCF f_SW_STST_CHG               ;si, clear flag cambio stato
        BCF f_INIT                      ;disattiva stato "init"
        BCF c_LED_GREEN_PORT,c_LED_GREEN_PIN ;attiva led rosso
        BSF c_LED_RED_PORT,c_LED_RED_PIN
        BSF f_REL_CMD                   ;attiva relè
        BCF f_TMR_END                   ;clear flag fine conteggio

P_INIT  BTFSS f_TIMER1_ON               ;Controlla se avvenuto IRQ timer1
        GOTO PROGRAM                    ; no, torna a inizio ciclo

;esecuzione con timer1
        BCF f_TIMER1_ON                 ;clear flag IRQ timer1

        CALL Sys_Ctrl                   ;chiama sub gestione sistema
        CALL Keyb_Read                  ;Chiama sub lettura pulsanti

        BTFSC f_INIT
        GOTO P_TMR2                     ;se in init, non esegue il seguente
        BTFSS f_SW_STST_STAT            ;verifica se premuto "start"
        GOTO $+5                        ;no, prosegue
        BTFSS f_SW_STST_CHG             ;si, verifica se cambio stato
        GOTO $+3                        ;no, prosegue
        BCF f_SW_STST_CHG               ;si, clear flag cambio stato
        BSF f_INIT                      ;attiva stato "init"

P_TMR2  INCF b_TMR2,F                   ;incrementa contatore timer2
        CMPBL b_TMR2,c_TMR_TIME2        ;verifica se timer2 arrivato al valore 
        BC $+3                          ;
        CLRF b_TMR2                     ; si, azzera contatore
        GOTO $+2
        GOTO PROGRAM                    ; no, torna a inizio ciclo

;esecuzione con timer2 (500ms)
        CALL Disp_Blink                 ;aggiorna lampeggio display
        BTFSC f_INIT
        GOTO PROGRAM                    ;se in init, non prosegue
        CALL Dot_Change                 ;aggiorna lampeggio punto decimale
        BTFSS f_TIMER3                  ;toggle per attivazione timer3
        GOTO $+3
        BCF f_TIMER3
        GOTO PROGRAM                    ;timer3 non attivo, torna a inizio ciclo

;esecuzione con timer3 (1s)
        BSF f_TIMER3                    ;toggle per attivazione timer3
        BTFSC f_TMR_END                 ;verifica se conteggio finito
        GOTO TMR_END                    ;si, passa alla fine
        BTFSS f_MODE                    ;controlla la modalità di conteggio
        GOTO $+3
        CALL Min_Cnt                    ;chiama sub conteggio min.sec
        GOTO $+2
        CALL Sec_Cnt                    ;chiama sub conteggio sec.
        GOTO PROGRAM                    ;Torna a inizio ciclo
TMR_END BSF c_LED_GREEN_PORT,c_LED_GREEN_PIN;attiva led verde
        BCF c_LED_RED_PORT,c_LED_RED_PIN
        BCF f_REL_CMD                   ;disattiva relè
        GOTO PROGRAM                    ;Torna a inizio ciclo

#include "display.inc"
#include "timer.inc"
#include "buffers.inc"
#include "control.inc"
#include "keyboard.inc"

        END

